@@ -17,6 +17,10 @@
 # under the License.
 #
 
+use strict;
+use warnings;
+use cproton_perl;
+
 package qpid::proton::Tracker;
 
 sub new {
@@ -26,13 +30,13 @@ sub new {
     $self->{_impl} = $_[1];
 
     bless $self, $class;
-
     return $self;
 }
 
 sub get_impl {
     my ($self) = @_;
 
+
     return $self->{_impl};
 }
 
